C     ECATFPG MODEL
C     MAIN.FOR
C     PROGRAM CONTROL AND GENERATE ECATF PARAMETERS
                               

C     DECLARE VARIABLES

C     STATION_ID: STATION IDENTIFICATION NUMBER                               
      INTEGER STATION_ID                       
C     MAX_ARRTIME: MAXIMUM ARRIVAL TIME     
      INTEGER MAX_ARRTIME
C     MYEARS: MAXIMUM POSSIBLE NUMBER OF YEARS
      INTEGER MYEARS
C     NYEARS: COUNTER OF YEARS
      INTEGER NYEARS
C     ACTUAL NUMBER OF YEARS IN DAILY RAINFALL DATA
      INTEGER YEARS
C     RAINYEAR: YEAR RECORD OF DAILY RAINFALL DATA           
      INTEGER RAINYEAR(1:100)                     
C     RAINDATA: DAILY RAINFALL DATA      
      REAL RAINDATA(100,1:400)
C     NDAYS: NUMBER OF DAILY RAINFALL RECORDS      
      INTEGER NDAYS(1:5000)
C     N_RAIN: NUMBER OF WAITING EVENT WRT ARRIVAL TIME
      INTEGER N_RAIN(1:1000)
C     N_RAIN_NORM: NORMALIZED N_RAIN BY NDAYS
      REAL N_RAIN_NORM(1:1000)
C     INDEX_WTEVT: COUNTER and INDEX  FOR WAITING EVENTS
      INTEGER INDEX_WTEVT      
C     ECATF PARAMETERS
      REAL ECATF_1(1:1000)

C     VARIABLE INITIALIZATION      
      MYEARS = 100
      NYEARS = 1

C     CHECK INPUT AND OUTPUT FILES
      CALL FILEIO
C     INPUT AND OUTPUT OF STATION_ID      
      READ(11, 5010) STATION_ID
      WRITE(12, 6010) 'STN_ID', STATION_ID
5010  FORMAT(I4)                      
6010  FORMAT(A9, I9)
      REWIND(11)

C     FIND NUMBER OF YEARS IN RAINFALL DATA FILE            
      DO 1020 I=1, MYEARS
       READ (11, 5020) RAINYEAR(I)
       IF (.NOT. EOF(11)) THEN
        NYEARS = NYEARS + 1
       ELSE
        GOTO 1050
       END IF
1020  CONTINUE      
1050  YEARS=NYEARS
5020  FORMAT (7X,I4)
      REWIND(11)

C     GET DAILY RAINFALL DATA FILE           
      DO 300, J=1, YEARS
      READ(11,5100) (RAINDATA(J,K), K=1,366)
300   CONTINUE
5100  FORMAT (11X, 366(1X,F6.2), 3X)

C     SORT OUT WAITING EVENTS FROM
      INDEX_WTEVT = 0
      DO 500, I= 1, YEARS
       DO 600, J = 1, 366
C     A ZERO RAIN-DAY
        IF (RAINDATA(I,J) .EQ. 0.00) THEN
C     A STARTING POINT OF WAITING EVENTS
         IF (RAINDATA(I,J-1) .NE. 0.00) THEN 
C     TOTAL NUMBER OF WAITING EVENTS INCREASE BY ONE
          INDEX_WTEVT = INDEX_WTEVT + 1
C     FOR A NEW WAITING EVENT, ARRIVAL TIME INCREASE BY ONE          
          NDAYS(INDEX_WTEVT)=NDAYS(INDEX_WTEVT) + 1
          GOTO 600
         ELSE
C     FOR A OLD WAITING EVENT, ARRIVAL TIME INCREASE BY ONE 
          NDAYS(INDEX_WTEVT)=NDAYS(INDEX_WTEVT) + 1
          GOTO 600
         END IF 
        ELSE
         GOTO 600
        END IF
600    CONTINUE
500   CONTINUE

C     FIND MAXIMUM ARRIVAL TIME      
      DO 1610, I = 1, INDEX_WTEVT
       IF (MAX_ARRTIME .GE. NDAYS(I)) THEN
        GOTO 1610
       ELSE
        MAX_ARRTIME = NDAYS(I)
       END IF
1610  CONTINUE         
            
C     FIND NUMBER OF WAITING EVENTS FOR EACH ARRIVAL TIME
      DO 1220, J = 1, MAX_ARRTIME
       DO I = 1, INDEX_WTEVT
        IF (J .EQ. NDAYS(I)) THEN
         N_RAIN(J) = N_RAIN(J) + 1
        END IF
       END DO  
1220  CONTINUE

C     OUTPUT FILE TITLES            
      WRITE(12, 6040) 'M_ARRTIME', MAX_ARRTIME
6040  FORMAT (A9, I9)      
      WRITE(12, 6050) 'ARR_T', 'ECATF'

C     GENERATE NORMALIZED WAITING EVENTS
      DO 800, I = 1, MAX_ARRTIME
       N_RAIN_NORM(I) = FLOAT(N_RAIN(I)) / FLOAT(INDEX_WTEVT)  
800   CONTINUE

C     GENERATE ECATF PARAMETERS      
      DO 1710, I = 1, MAX_ARRTIME
       IF (I .EQ. 1) THEN
        ECATF_1(1) = N_RAIN_NORM(1) 
        GOTO 1720
       END IF
       ECATF_1(I) = ECATF_1(I-1) + N_RAIN_NORM(I)
1720   WRITE(12, 6060) I, ECATF_1(I)  
1710  CONTINUE

6050  FORMAT(A9, A9)
6060  FORMAT(I9, F9.4)

      CLOSE(11)
      CLOSE(12)
      END        
